@@ -1,4 +1,4 @@
-from log_tools import *
+from main_log import *
 
 __all__ = ['MainLog', ]
 
